@@ -1,13 +1,35 @@
 # -*- python -*-
+#
+# Copyright (C) 2001,2002 Jason R. Mastaler <jason@mastaler.com>
+#
+# This file is part of TMDA.
+#
+# TMDA is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.  A copy of this license should
+# be included in the file COPYING.
+#
+# TMDA is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+# for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with TMDA; if not, write to the Free Software Foundation, Inc.,
+# 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
 """TMDA configuration variable defaults."""
 
 
+import binascii
 import os
 import stat
 import string
 import sys
 
+import Errors
+
 
 ##############################
 # General system-wide defaults
@@ -22,6 +44,17 @@ PID = str(os.getpid())
 EX_OK = 0                               
 EX_TEMPFAIL = 75
 
+# TMDA parent directory.
+progpath = os.path.abspath(sys.argv[0])
+if os.path.islink(progpath):
+    progdir = os.path.dirname(progpath)
+    linkpath = os.readlink(progpath)
+    if os.path.isabs(linkpath):
+        progpath = linkpath
+    else:
+        progpath = os.path.normpath(progdir + '/' + linkpath)
+PARENTDIR = os.path.split(os.path.dirname(progpath))[0] # '../'
+
 # If the file /etc/tmdarc exists, read it before ~/.tmdarc.
 # Make site-wide configuration changes to this file.
 GLOBAL_TMDARC = '/etc/tmdarc'
@@ -34,13 +67,14 @@ if os.path.exists(GLOBAL_TMDARC):
 # Look for the user-config-file in the environment first then default
 # to ~/.tmdarc.
 TMDARC = os.environ.get('TMDARC')
-if not TMDARC:TMDARC = os.path.expanduser("~/.tmdarc")
+if not TMDARC:
+    TMDARC = os.path.expanduser("~/.tmdarc")
 
 # Read-in the user's configuration file.
-if not os.path.exists(TMDARC):
-    print "Can't open configuration file:",TMDARC
-    sys.exit(EX_TEMPFAIL)
-execfile(TMDARC)
+if os.path.exists(TMDARC):
+    execfile(TMDARC)
+else:
+    raise Errors.ConfigError, "Can't open configuration file: " + TMDARC
 
 # Check for proper file permissions before proceeding.
 statinfo = os.stat(TMDARC)
@@ -56,10 +90,7 @@ if not vars().has_key('ALLOW_MODE_640'):
 if ALLOW_MODE_640 and mode in (400, 600, 640):
     pass
 elif mode not in (400, 600):
-    print TMDARC,"must be permission mode 400 or 600!"
-    sys.exit(EX_TEMPFAIL)
-else:
-    pass
+    raise Errors.ConfigError, TMDARC + " must be chmod 400 or 600!"
 
 
 import Util
@@ -99,8 +130,8 @@ if not vars().has_key('MAIL_TRANSFER_AGENT'):
 if not vars().has_key('LOCAL_DELIVERY_AGENT'):
     LOCAL_DELIVERY_AGENT = None
 if MAIL_TRANSFER_AGENT != 'qmail' and not LOCAL_DELIVERY_AGENT:
-    print "Not running qmail: you must define LOCAL_DELIVERY_AGENT in",TMDARC
-    sys.exit(EX_TEMPFAIL)
+    raise Errors.ConfigError, \
+          "non-qmail must define LOCAL_DELIVERY_AGENT in " + TMDARC
 
 # RECIPIENT_DELIMITER
 # A single character which specifies the separator between user names
@@ -116,16 +147,10 @@ if not vars().has_key('RECIPIENT_DELIMITER'):
 # interface.  Defaults to one of the two standard locations, but you
 # can override it in case it is installed elsewhere.
 if not vars().has_key('SENDMAIL'):
-    if os.path.exists("/usr/sbin/sendmail"):
-        SENDMAIL = "/usr/sbin/sendmail"
-    elif os.path.exists("/usr/lib/sendmail"):
-        SENDMAIL = "/usr/lib/sendmail"
-    else:
-        print "Can't find your sendmail program!"
-        sys.exit(EX_TEMPFAIL)
-elif not os.path.exists(SENDMAIL):
-    print "Invalid SENDMAIL path:",SENDMAIL
-    sys.exit(EX_TEMPFAIL)
+    for sendmail in ('/usr/sbin/sendmail', '/usr/lib/sendmail'):
+        if os.path.exists(sendmail):
+            SENDMAIL = sendmail
+            break
 
 # USEVIRTUALDOMAINS
 # Set this variable to 0 if want to turn off TMDA's qmail virtualdomains
@@ -151,7 +176,7 @@ if not vars().has_key('BOUNCE_ENV_SENDER'):
         BOUNCE_ENV_SENDER = '<>'
     else:
         BOUNCE_ENV_SENDER = ''
-
+        
 # BARE_APPEND
 # Filename to which a recipient's e-mail address should be
 # automatically appended if the outgoing <action> is in the form
@@ -160,6 +185,17 @@ if not vars().has_key('BOUNCE_ENV_SENDER'):
 if not vars().has_key('BARE_APPEND'):
     BARE_APPEND = None
 
+# CONFIRM_ADDRESS
+# An optional e-mail address to use for creating confirmation
+# addresses.  Normally, the recipient address is used, but in some
+# virtual domain or forwarding scenarios, you may wish to have
+# confirmation address be based on a fixed address regardless of the
+# recipient address.
+#
+# No default
+if not vars().has_key('CONFIRM_ADDRESS'):
+    CONFIRM_ADDRESS = None
+
 # CONFIRM_APPEND
 # Filename to which a sender's e-mail address should be automatically
 # appended once they confirm a message.  This can be used to implement
@@ -167,7 +203,7 @@ if not vars().has_key('BARE_APPEND'):
 # No default
 if not vars().has_key('CONFIRM_APPEND'):
     CONFIRM_APPEND = None
-
+    
 # CONFIRM_CC
 # An optional e-mail address which will be sent a copy of any message
 # that triggers a confirmation request.
@@ -200,19 +236,13 @@ if not vars().has_key('CONFIRM_MAX_MESSAGE_SIZE'):
 # Full path to a custom template for confirmation acceptance notices.
 # Default is confirm_accept.txt in ../templates/.
 if not vars().has_key('CONFIRM_ACCEPT_TEMPLATE'):
-    ca_template = '/templates/confirm_accept.txt'
-    CONFIRM_ACCEPT_TEMPLATE = os.path.split(os.path.dirname
-                                            (os.path.abspath
-                                             (sys.argv[0])))[0] + ca_template 
-
+    CONFIRM_ACCEPT_TEMPLATE = PARENTDIR + '/templates/confirm_accept.txt'
+    
 # CONFIRM_REQUEST_TEMPLATE
 # Full path to a custom template for confirmation requests.
 # Default is confirm_request.txt in ../templates/.
 if not vars().has_key('CONFIRM_REQUEST_TEMPLATE'):
-    cr_template = '/templates/confirm_request.txt'
-    CONFIRM_REQUEST_TEMPLATE = os.path.split(os.path.dirname
-                                            (os.path.abspath
-                                             (sys.argv[0])))[0] + cr_template 
+    CONFIRM_REQUEST_TEMPLATE = PARENTDIR + '/templates/confirm_request.txt'
 
 # DATED_TEMPLATE_VARS
 # Set this variable to 1 if you want to use 'dated' address variables
@@ -233,13 +263,12 @@ if not vars().has_key('SENDER_TEMPLATE_VARS'):
 # Use the included "tmda-keygen" program to generate your key.
 # No default.
 if not vars().has_key('CRYPT_KEY'):
-    print "Encryption key not found!"
-    sys.exit(EX_TEMPFAIL)
+    raise Errors.ConfigError, "CRYPT_KEY not defined in " + TMDARC
 else:
     # Convert key from hex back into raw binary.
     # Hex has only 4 bits of entropy per byte as opposed to 8.
-    CRYPT_KEY = Util.unhexlify(CRYPT_KEY)
-
+    CRYPT_KEY = binascii.unhexlify(CRYPT_KEY)
+    
 # FILTER_INCOMING
 # Filter file which controls how incoming messages are tagged.
 # Default is ~/.tmda/filters/incoming
@@ -301,15 +330,21 @@ if not vars().has_key('ACTION_INCOMING'):
 # are no matches in FILTER_OUTGOING and no X-TMDA header.
 # Possible values include:
 #
-# "bare"
+# "bare[=append]"
 #    don't tag
 #
-# "dated"
+# "dated[=timeout_interval]"
 #    tag with a dated address
 #
-# "sender"
+# "sender[=sender_address]"
 #    tag with a sender address
 #
+# "exp=full_address"
+#    tag with explicit address
+#
+# "kw=keyword"
+#    tag with a keyword address
+#
 # Default is dated
 if not vars().has_key('ACTION_OUTGOING'):
     ACTION_OUTGOING = "dated"
@@ -317,16 +352,18 @@ if not vars().has_key('ACTION_OUTGOING'):
 # FINGERPRINT
 #
 # A list containing one or more message headers whose values should be
-# used to create a "fingerprint" for the message.  The fingerprint is
-# a SHA-1 HMAC digest represented as a base64-encoded string.  This
-# fingerprint will be added to your outgoing client-side messages
-# (i.e, messages sent with tmda-sendmail) in an `X-TMDA-Fingerprint'
-# header prior to injection.
+# used to create a "fingerprint" for the message.  If the header value
+# is 'body' (all-lowercase), the message body content is used instead
+# of a header value.  The fingerprint is a SHA-1 HMAC digest
+# represented as a base64-encoded string.  This fingerprint will be
+# added to your outgoing client-side messages (i.e, messages sent with
+# tmda-sendmail) in an `X-TMDA-Fingerprint' header prior to injection.
 #
 # Examples:
 #
 # FINGERPRINT = ["message-id"]
 # FINGERPRINT = ["message-id", "from", "date"]
+# FINGERPRINT = ["message-id", "body"]
 #
 # Things to keep in mind, especially if verifying these fingerprints
 # with non-TMDA code.
@@ -415,6 +452,24 @@ if not vars().has_key('LOGFILE_INCOMING'):
 if not vars().has_key('MESSAGE_FROM_STYLE'):
     MESSAGE_FROM_STYLE = "angles"
 
+# PENDING_CACHE
+# Path to the cache file used when tmda-pending is invoked with the
+# --cache option.
+#
+# Default is ~/.tmda/pending/.msgcache
+if not vars().has_key('PENDING_CACHE'):
+    PENDING_CACHE = DATADIR + 'pending/.msgcache'
+
+# PENDING_CACHE_LEN
+# An integer which specifies the maximum number of entries held by
+# PENDING_CACHE.  Make sure this is greater than the number of
+# messages kept in your pending queue, or else you'll start seeing
+# previously viewed messages again.
+#
+# Default is 5000
+if not vars().has_key('PENDING_CACHE_LEN'):
+    PENDING_CACHE_LEN = 5000
+
 # PURGED_HEADERS
 # A list containing one or more message headers that should be removed
 # from outgoing client-side messages (i.e, messages sent with
